@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import StatusType, SuiteRunStatusType
 
@@ -61,7 +61,7 @@ CreateSuiteDefinitionRequestRequestTypeDef = TypedDict(
     "CreateSuiteDefinitionRequestRequestTypeDef",
     {
         "suiteDefinitionConfiguration": "SuiteDefinitionConfigurationTypeDef",
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -257,7 +257,7 @@ _OptionalStartSuiteRunRequestRequestTypeDef = TypedDict(
     {
         "suiteDefinitionVersion": str,
         "suiteRunConfiguration": "SuiteRunConfigurationTypeDef",
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -291,7 +291,7 @@ SuiteDefinitionConfigurationTypeDef = TypedDict(
     "SuiteDefinitionConfigurationTypeDef",
     {
         "suiteDefinitionName": str,
-        "devices": List["DeviceUnderTestTypeDef"],
+        "devices": Sequence["DeviceUnderTestTypeDef"],
         "intendedForQualification": bool,
         "rootGroup": str,
         "devicePermissionRoleArn": str,
@@ -341,7 +341,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
 )
 
@@ -373,7 +373,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
